package de.laliluna.tutorial.databaseview.entity.ejb;

import java.rmi.RemoteException;

import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;

import de.laliluna.tutorial.databaseview.entity.interfaces.BookViewValue;

/**
 * @author laliluna.de
 * 
 * @ejb.bean name="BookView"
 *           display-name="Name for BookView"
 *           description="Description for BookView"
 *           jndi-name="ejb/BookView"
 *           type="CMP"
 *           cmp-version="2.x"
 *           view-type="local"
 * 			 primkey-field = "id"
 * 
 * @ejb.util generate="physical"
 * @ejb.persistence table-name = "vbook"   
 * @ejb.value-object match = "*" name="BookView" 
 * 
 * @jboss.persistence create-table = "false" 
 * 			    	  remove-table = "false" 
 * 					  read-only = "true"
 * 
 * @ejb.finder description = "Find all"
 * 			   signature = "java.util.Collection findAll()" 
 * 			   query = "select object(c) from BookView as c"
 * 
 * @jboss.entity-command name="postgresql-fetch-seq"
 */
public abstract class BookView implements EntityBean {
    
    
    /**
     * @ejb.interface-method view-type = "local"
     * @ejb.persistence column-name = "fid"
     * 					
     * @ejb.pk-field 
     * @jboss.persistence auto-increment = "true"
     * 					  
     * @return
     */
    public abstract Integer getId();

    /**
     * @ejb.interface-method view-type = "local"
     * @param id
     */
    public abstract void setId(Integer id);
    
    
    /**
     * @ejb.interface-method view-type = "local"
     * @ejb.persistence column-name = "ftitle"
     * 					
     * @return
     */
    public abstract String getTitle();

    /**
     * @ejb.interface-method view-type = "local"
     * @param title
     */
    public abstract void setTitle(String title);
    
    /**
     * @ejb.interface-method view-type = "local"
     * @return
     */
    public abstract BookViewValue getBookViewValue();

    /**
     * @ejb.interface-method view-type = "local"
     * @param bookViewValue
     */
    public abstract void setBookViewValue(BookViewValue bookViewValue);
    

    /** The entity context */
    private EntityContext context;


    /**
     * Set the associated entity context. The container calls this method 
     * after the instance creation. The entity bean must not attempt to 
     * access its persistent state and relationships using the accessor 
     * methods during this method. <br>
     *
     * The enterprise bean instance should store the reference to the context 
     * object in an instance variable. <br>
     * 
     * This method is called with no transaction context. 
     * 
     * @throws EJBException Thrown if method fails due to system-level error.
     */
    public void setEntityContext(EntityContext newContext) throws EJBException {
        context = newContext;
    }

    /**
     * Unset the associated entity context. A container invokes this method 
     * before terminating the life of the instance. The entity bean must not 
     * attempt to access its persistent state and relationships using the 
     * accessor methods during this method. <br>
     * 
     * This method is called with no transaction context. 
     * 
     * @throws EJBException Thrown if method fails due to system-level error.
     */
    public void unsetEntityContext() throws EJBException {
        context = null;
    }

    /* (non-Javadoc)
     * @see javax.ejb.EntityBean#ejbActivate()
     */
    public void ejbActivate() throws EJBException, RemoteException {
    }

    /* (non-Javadoc)
     * @see javax.ejb.EntityBean#ejbPassivate()
     */
    public void ejbPassivate() throws EJBException, RemoteException {
    }

    /* (non-Javadoc)
     * @see javax.ejb.EntityBean#ejbLoad()
     */
    public void ejbLoad() throws EJBException, RemoteException {
    }

    /* (non-Javadoc)
     * @see javax.ejb.EntityBean#ejbStore()
     */
    public void ejbStore() throws EJBException, RemoteException {
    }

}